﻿using Syncfusion.XlsIO;
using System;
using System.IO;
using System.Reflection;
using Xamarin.Forms;

namespace Sample
{
    public partial class MainPage : ContentPage
    {
        public MainPage()
        {
            InitializeComponent();

        }

        async void OnButtonClicked(object sender, EventArgs args)
        {
            ExcelEngine excelEngine = new ExcelEngine();
            IApplication application = excelEngine.Excel;

            application.DefaultVersion = ExcelVersion.Excel2013;

            #region Initializing Workbook
            string resourcePath = "Sample.Template.Sample.xlsx";
            Assembly assembly = typeof(App).GetTypeInfo().Assembly;
            Stream fileStream = assembly.GetManifestResourceStream(resourcePath);

            IWorkbook workbook = application.Workbooks.Open(fileStream);

            IWorksheet sheet = workbook.Worksheets[0];
			sheet.EnableSheetCalculations();  
            #endregion

            ContentPage gridView = new ContentPage();
			ScrollView view = new ScrollView ();
			view.Orientation = ScrollOrientation.Horizontal;
			view.Content = 	GetGridData(sheet);
			gridView.Content = view;
            await Navigation.PushModalAsync(gridView);

        }

        private Grid GetGridData(IWorksheet sheet)
        {
            Grid controlGrid = new Grid { RowSpacing = 1, ColumnSpacing = 1 };

		
			IRange range = sheet.UsedRange;

			for (int row = 1; row <= range.LastRow; row++)
            {
				controlGrid.RowDefinitions.Add(new RowDefinition { Height = new GridLength(sheet.GetRowHeightInPixels(row) )  });
            }

			for (int column = 1; column <= range.LastColumn; column++)
            {
				controlGrid.ColumnDefinitions.Add(new ColumnDefinition { Width = new GridLength(sheet.GetColumnWidthInPixels(column))});
            }

			IMigrantRange migrantRange = sheet.MigrantRange;
			for (int row = 1; row <= range.LastRow; row++) 
			{
				for (int column = 1; column <= range.LastColumn; column++) 
				{
					migrantRange.ResetRowColumn (row, column);
					IStyle style = migrantRange.CellStyle;
					IFont font = style.Font;
					Label label = new Label ();
					label.Text = migrantRange.DisplayText;
					label.FontFamily = font.FontName;
					label.FontSize = font.Size;
					label.HorizontalTextAlignment = style.HorizontalAlignment == ExcelHAlign.HAlignCenter ? TextAlignment.Center : style.HorizontalAlignment == ExcelHAlign.HAlignRight ? TextAlignment.End : TextAlignment.Start;
					label.BackgroundColor = new Color (style.Color.R, style.Color.G, style.Color.B );
					if (migrantRange.IsMerged) {
						IRange merged = migrantRange.MergeArea;

						controlGrid.Children.Add (label, column - 1, row - 1);
						Grid.SetColumnSpan (label, merged.LastColumn - column + 1);
						column = merged.LastColumn;
					} 
					else 
					{
						controlGrid.Children.Add (label, column - 1, row - 1);
					}


				}
			}

            return controlGrid;
        }

    }
}
